/*

OSEPP 101 Sensor Kit 

OSEPP SECURITY SYSTEM EXAMPLE

detect if an intruder is within range of our ping sensor, or 
other movements are detected to send a buzzing alert. Also listen to
ambient sounds. 

*/

#include <NewPing.h>

//////PING sensor////////////
#define TRIGGER_PIN  2  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     3  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 200 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.
int pingMeasure; //final ping measurements in cm
NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.


/////////////////////////////
//the time we give the sensor to calibrate (10-60 secs according to the datasheet)
int calibrationTime = 10;        

//the time when the sensor outputs a low impulse
long unsigned int lowIn;         

//the amount of milliseconds the sensor has to be low 
//before we assume all motion has stopped
long unsigned int pause = 5000;  

boolean lockLow = true;
boolean takeLowTime;  

int pirPin = 11;    //the digital pin connected to the PIR sensor's output
int micPin =A5; //microphone 
int micVal;
int buzzerAlarm = 9;


//////////////////
void setup(){
  Serial.begin(9600);
  pinMode(pirPin, INPUT);
  pinMode(buzzerAlarm, OUTPUT);
  digitalWrite(pirPin, LOW);

  //give the sensor some time to calibrate
  Serial.print("calibrating sensor ");
    for(int i = 0; i < calibrationTime; i++){
      Serial.print(".");
      delay(1000);
      }
    Serial.println(" done");
    Serial.println("SENSOR ACTIVE");
    delay(50);

  
  }

////////////////////////////

void loop(){
  
  delay(50);
  micVal= analogRead(micPin);
  Serial.println(micVal);
  
  if(micVal > 100){ //if loudness threshold is reached, buzz alarm
    digitalWrite(buzzerAlarm, HIGH);   //the led visualizes the sensors output pin state

  }
  else if (micBal < 100){
        digitalWrite(buzzerAlarm, LOW);   //the led visualizes the sensors output pin state

  }


     if(digitalRead(pirPin) == HIGH){
digitalWrite(buzzerAlarm, HIGH);   //the led visualizes the sensors output pin state
       if(lockLow){  
         //makes sure we wait for a transition to LOW before any further output is made:
         lockLow = false;            
         Serial.println("---");
         Serial.print("motion detected at ");
         Serial.print(millis()/1000);
         Serial.println(" sec"); 
         delay(50);

//Send a 'Ping' to ping sensor, resulting in Ping reading when PIR sensor is active (HIGH state).
  unsigned int uS = sonar.ping(); // Send ping, get ping time in microseconds (uS).
  Serial.print("Ping: ");
  pingMeasure = uS / US_ROUNDTRIP_CM;
  Serial.print(pingMeasure); // Convert ping time to distance in cm and print result (0 = outside set distance range)
  Serial.println("cm");
  
         }         
         takeLowTime = true;
       }

     if(digitalRead(pirPin) == LOW){       
       digitalWrite(buzzerAlarm, LOW);  //the led visualizes the sensors output pin state

       if(takeLowTime){
        lowIn = millis();          //save the time of the transition from high to LOW
        takeLowTime = false;       //make sure this is only done at the start of a LOW phase
        }
       //if the sensor is low for more than the given pause, 
       //we assume that no more motion is going to happen
       if(!lockLow && millis() - lowIn > pause){  
           //makes sure this block of code is only executed again after 
           //a new motion sequence has been detected
           lockLow = true;                        
           Serial.print("motion ended at ");      //output
           Serial.print((millis() - pause)/1000);
           Serial.println(" sec");
           delay(50);
           }
       }
  }

